# dash-lazy-load

StratoDem Analytics Dash implementation of `react-lazyload`

Dash wrappers around the excellent [`react-lazyload`](https://github.com/jasonslylvia/react-lazyload) package

### Examples
![Lazy Load Example](https://github.com/mjclawar/dash-lazy-load/blob/master/LazyLoadExample.gif)
The blue border component loads in after a debounce period on scroll(!)

### Dash

Go to this link to learn about [Dash][].

## Dash help

See the [dash-components-archetype][] repo for more information.

## Contributing
To set up the development environment:

```shell
$ npm install
# Run webpack to create the Dash React bundle
$ npm run build-dist
# Set up a virtualenv
$ virtualenv venv -p python3
$ source venv/bin/activate
# Install the local Py
$ npm run install-local
```

### Running a local server
Run `usage.py` in the virtual environment
```
$ source venv/bin/activate
$ python usage.py
```

[Dash]: https://github.com/plotly/dash
[dash-components-archetype]: https://github.com/plotly/dash-components-archetype

### Contributors
[@mjclawar](https://github.com/mjclawar)
[@wchaering](https://github.com/wchaering)
